@@ -47,10 +47,11 @@ release = pyudev.__version__
 html_theme = 'default'
 html_static_path = []
 
-intersphinx_mapping = {'python': ('http://docs.python.org/', None)}
+intersphinx_mapping = {'python': ('http://docs.python.org/', None),
+                       'pyside': ('http://www.pyside.org/docs/pyside/', None)}
 
 issuetracker = 'github'
-issuetracker_user = 'lunaryorn'
+issuetracker_project = 'lunaryorn/pyudev'
 
 
 class UDevMinimumVersion(Directive):
