@@ -31,9 +31,9 @@ from __future__ import (print_function, division, unicode_literals,
                         absolute_import)
 
 import os
-from errno import ENOMEM
+from errno import ENOMEM, EOVERFLOW
 from ctypes import (CDLL, Structure, POINTER, get_errno,
-                    c_char_p, c_int, c_ulonglong)
+                    c_char, c_char_p, c_int, c_ulonglong)
 from ctypes.util import find_library
 
 
@@ -78,6 +78,9 @@ class udev_monitor(Structure):
 udev_monitor_p = POINTER(udev_monitor)
 
 
+dev_t = c_ulonglong
+
+
 SIGNATURES = {
     # context
     'udev': dict(
@@ -113,6 +116,7 @@ SIGNATURES = {
         new_from_syspath=([udev_p, c_char_p], udev_device_p),
         new_from_subsystem_sysname=([udev_p, c_char_p, c_char_p],
                                     udev_device_p),
+        new_from_devnum=([udev_p, c_char, dev_t], udev_device_p),
         new_from_environment=([udev_p], udev_device_p),
         get_parent=([udev_device_p], udev_device_p),
         get_parent_with_subsystem_devtype=([udev_device_p, c_char_p, c_char_p],
@@ -120,12 +124,14 @@ SIGNATURES = {
         get_devpath=([udev_device_p], c_char_p),
         get_subsystem=([udev_device_p], c_char_p),
         get_syspath=([udev_device_p], c_char_p),
+        get_sysnum=([udev_device_p], c_char_p),
         get_sysname=([udev_device_p], c_char_p),
         get_driver=([udev_device_p], c_char_p),
         get_devtype=([udev_device_p], c_char_p),
         get_devnode=([udev_device_p], c_char_p),
         get_property_value=([udev_device_p, c_char_p], c_char_p),
         get_sysattr_value=([udev_device_p, c_char_p], c_char_p),
+        get_devnum=([udev_device_p], dev_t),
         get_action=([udev_device_p], c_char_p),
         get_is_initialized=([udev_device_p], c_int),
         get_usec_since_initialized=([udev_device_p], c_ulonglong),
@@ -150,18 +156,28 @@ SIGNATURES = {
 
 def check_negative_errorcode(result, func, *args):
     """
-    Check if ``result`` is ``0``.  If so, return normally.  Otherwise interpret
-    ``result`` as negative error code, and raise
-    :exc:`~exceptions.MemoryError`, if ``result`` is ``-ENOMEM``, or
-    :exc:`~exceptions.EnvironmentError` in any other case.
+    Error checker for udev funtions, which return negative error codes.
+
+    If ``result`` is smaller than ``0``, it is interpreted as negative error
+    code, and an appropriate exception is raised:
+
+    - ``-ENOMEM`` raises a :exc:`~exceptions.MemoryError`
+    - ``-EOVERFLOW`` raises a :exc:`~exceptions.OverflowError`
+    - all other error codes raise :exc:`~exceptions.EnvironmentError`
+
+    If result is greater or equal to ``0``, it is returned unchanged.
     """
-    if result != 0:
+    if result < 0:
         # udev returns the *negative* errno code at this point
         errorcode = -result
-        if errorcode == ENOMEM:
-            raise MemoryError()
+        exceptions = {ENOMEM: MemoryError, EOVERFLOW: OverflowError}
+        exception = exceptions.get(errorcode)
+        if exception is not None:
+            raise exception()
         else:
             raise EnvironmentError(errorcode, os.strerror(errorcode))
+    else:
+        return result
 
 
 ERROR_CHECKERS = dict(
