@@ -98,9 +98,12 @@ def udev_list_iterate(entry):
     """
     Iteration helper for udev list entry objects.
 
-    Simply yield all next entries starting with ``entry``, until there is no
-    next entry anymore.
+    Yield a tuple ``(name, value)``.  ``name`` and ``value`` are bytestrings
+    containing the name and the value of the list entry.  The exact contents
+    depend on the list iterated over.
     """
     while entry:
-        yield libudev.udev_list_entry_get_name(entry)
+        name = libudev.udev_list_entry_get_name(entry)
+        value = libudev.udev_list_entry_get_value(entry)
+        yield (name, value)
         entry = libudev.udev_list_entry_get_next(entry)
