@@ -124,8 +124,8 @@ class DeviceNotFoundByNumberError(DeviceNotFoundError):
         return self.args[1]
 
     def __str__(self):
-        return 'No {0.device_type} device with number {0.device_number}'.format(
-            self)
+        return ('No {0.device_type} device with number '
+                '{0.device_number}'.format(self))
 
 
 class DeviceNotFoundInEnvironmentError(DeviceNotFoundError):
@@ -329,7 +329,6 @@ class Device(Mapping):
     def __init__(self, context, _device):
         self.context = context
         self._as_parameter_ = _device
-        self._attributes = Attributes(self)
 
     def __del__(self):
         libudev.udev_device_unref(self)
@@ -526,8 +525,8 @@ class Device(Mapping):
         Use :func:`os.major` and :func:`os.minor` to decompose the device
         number into its major and minor number:
 
-        >>> ctx = Context()
-        >>> sda = Device.from_name('block', 'sda')
+        >>> context = Context()
+        >>> sda = Device.from_name(context, 'block', 'sda')
         >>> sda.device_number
         2048L
         >>> (os.major(sda.device_number), os.minor(sda.device_number))
@@ -621,7 +620,11 @@ class Device(Mapping):
 
         .. versionadded:: 0.5
         """
-        return self._attributes
+        # do *not* cache the created object in an attribute of this class.
+        # Doing so creates an uncollectable reference cycle between Device and
+        # Attributes, because Attributes refers to this object through
+        # Attributes.device.
+        return Attributes(self)
 
     @property
     def tags(self):
