@@ -19,6 +19,7 @@ from __future__ import (print_function, division, unicode_literals,
                         absolute_import)
 
 import sys
+import os
 import re
 import random
 import subprocess
@@ -183,7 +184,8 @@ def _query_device(device_path, query_type):
     if query_type not in ('symlink', 'name'):
         raise ValueError(query_type)
     udevadm = subprocess.Popen(
-        ['udevadm', 'info', '--path', device_path, '--query', query_type],
+        ['udevadm', 'info', '--root', '--path', device_path,
+         '--query', query_type],
         stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     query_result = udevadm.communicate()[0].strip().decode(
         sys.getfilesystemencoding())
@@ -220,14 +222,24 @@ def patch_libudev_list(items, list_func):
         else:
             pytest.fail('empty entry!')
 
+    def value(entry):
+        if entry:
+            return 'value of {0}'.format(entry)
+        else:
+            pytest.fail('empty entry!')
+
     get_next = 'udev_list_entry_get_next'
     get_name = 'udev_list_entry_get_name'
+    get_value = 'udev_list_entry_get_value'
     with pytest.nested(pytest.patch_libudev(get_next),
                        pytest.patch_libudev(get_name),
+                       pytest.patch_libudev(get_value),
                        pytest.patch_libudev(list_func)) as (get_next, get_name,
-                                                           list_func):
+                                                            get_value,
+                                                            list_func):
         list_func.return_value = next(item_list)
         get_name.side_effect = name
+        get_value.side_effect = value
         get_next.side_effect = lambda e: next(item_list, None)
         yield list_func
 
@@ -398,6 +410,18 @@ def pytest_funcarg__device_node(request):
     return _query_device(device_path, 'name')
 
 
+def pytest_funcarg__device_number(request):
+    """
+    Return the device number of the device pointed to by the ``device_path``
+    funcarg.
+    """
+    device_node = request.getfuncargvalue('device_node')
+    if device_node:
+        return os.stat(device_node).st_rdev
+    else:
+        return 0
+
+
 def pytest_funcarg__device_links(request):
     """
     Return a list of symlink to the device node (``device_node`` funcarg)
