@@ -24,6 +24,7 @@ import os
 import stat
 import operator
 import sys
+import gc
 from itertools import count
 from datetime import timedelta
 
@@ -270,12 +271,35 @@ class TestDevice(object):
     def test_attributes(self, device):
         # see TestAttributes for complete attribute tests
         assert isinstance(device.attributes, Attributes)
-        assert device.attributes is device._attributes
 
-    @pytest.mark.xfail(reason='Not implemented')
+    def test_attributes_no_leak(self, context):
+        """
+        Regression test for issue #32, modelled after the script which revealed
+        this issue.
+
+        The leak was caused by the following reference cycle between
+        ``Attributes`` and ``Device``:
+
+        Device._attributes -> Attributes.device
+
+        https://github.com/lunaryorn/pyudev/issues/32
+        """
+        for _ in context.list_devices(subsystem='usb'):
+            pass
+        # make sure that no memory leaks
+        assert not gc.garbage
+
     @pytest.need_udev_version('>= 154')
-    def test_device_tags(self):
-        raise NotImplementedError()
+    def test_device_tags(self, device):
+        try:
+            is_input_device = (device.asbool('ID_INPUT_MOUSE') or
+                               device.asbool('ID_INPUT_KEYBOARD'))
+        except KeyError:
+            is_input_device = False
+        if is_input_device:
+            assert 'seat' in device.tags
+        else:
+            pytest.skip('no tags known for device')
 
     @pytest.need_udev_version('>= 154')
     def test_device_tags_mock(self, device):
